@@ -3,7 +3,7 @@ from django.conf import settings
 import views
 
 urlpatterns = patterns('',
-	('^(?P<model>\w+)/(?P<function>\w+)', views.json_api)
+	('^(?P<model>\w+)/(?P<function>\w+)', views.json_api_timeout)
 )
 
 if settings.DEBUG:
